Add Qwen3.6 MoE inference support

This commit is contained in:
2026-07-13 20:24:41 +08:00
parent 588bfd9df3
commit a2de146fb6
27 changed files with 3153 additions and 149 deletions

View File

@@ -21,11 +21,11 @@
// active batch) so we just index by blockIdx.x_seq.
// context_lens [batch] int32 — number of valid tokens per sequence.
//
// One CUDA block: 256 threads, head_dim <= 128.
// One CUDA block: 256 threads, head_dim <= 256.
#define PAGED_BLOCK_SIZE 16
#define PAGED_THREADS 256
#define PAGED_HEAD_DIM_MAX 128
#define PAGED_HEAD_DIM_MAX 256
__global__ void paged_decode_attention_bf16_kernel(
const __nv_bfloat16* __restrict__ Q,